Bika LIMS
=========

The meaning of Gaob
-------------------

In the tradition of Chief Inkosi Bika LIMS 2 using a title for a release, this
edition is code-named Gaob Bika LIMS 3. Gaob, King, is taken from Khoi San Nama,
language of the world's first people.

Installation
------------

* `Installing Bika LIMS <https://github.com/bikalabs/Bika-LIMS/blob/0c606e0/INSTALL.rst>`_

Documentation
-------------

* `User Manual <http://demo.bikalabs.com/knowledge-centre/manual/bika-3-user-manual>`_
* `GitHub Wiki <github.com/bikalabs/Bika-LIMS/wiki>`_

Feedback and support
--------------------

* Bika Users List: `bika-users <http://lists.sourceforge.net/lists/listinfo/bika-users>`_
* Bika Developers List: `bika-developers <http://lists.sourceforge.net/lists/listinfo/bika-developers>`_
* LIMS design List: `lims-design <https://groups.google.com/forum/?hl=en#%21forum/bika-design>`_
* Issue Tracker: `http://jira.bikalabs.com/ <http://jira.bikalabs.com>`_
* IRC: `irc://freenode.net/#bika <irc://freenode.net/#bika>`_

